@@ -27,7 +27,7 @@ else:
 	from defaultpaths import (xdg_config_dir_default, xdg_config_home, 
 							  xdg_data_home, xdg_data_home_default, 
 							  xdg_data_dirs)
-from defaultpaths import (autostart, autostart_home, iccprofiles,
+from defaultpaths import (autostart, autostart_home, home, iccprofiles,
 						  iccprofiles_home)
 from meta import name as appname, build, lastmod, version
 from options import ascii, debug, verbose
@@ -36,6 +36,7 @@ from util_io import StringIOu as StringIO
 from util_os import (expanduseru, expandvarsu, getenvu, is_superuser,
 					 listdir_re, which)
 from util_str import create_replace_function, safe_unicode, strtr
+import colormath
 import encodedstdio
 
 # Runtime configuration
@@ -153,8 +154,8 @@ resfiles = [
 	"ref/ClayRGB1998.gam",
 	"ref/sRGB.gam",
 	"ref/verify_extended.ti1",
-	"ti1/d3-e4-s0-g25-m3-b3-f0-crossover.ti1",
-	"ti1/d3-e4-s0-g49-m3-b3-f0-crossover.ti1",
+	"ti1/d3-e4-s2-g25-m0-b0-f0.ti1",
+	"ti1/d3-e4-s2-g49-m0-b0-f0.ti1",
 	"ti1/d3-e4-s13-g37-m4-b4-f0.ti1",
 	"ti1/d3-e4-s17-g49-m5-b5-f0.ti1",
 	"xrc/extra.xrc",
@@ -510,7 +511,8 @@ def get_data_path(relpath, rex=None):
 		return None
 	dirs = list(data_dirs)
 	argyll_dir = (getcfg("argyll.dir") or
-				  os.path.dirname(os.path.realpath(which("dispcal") or "")))
+				  os.path.dirname(os.path.realpath(which("dispcal" +
+														 exe_ext) or "")))
 	if argyll_dir and os.path.isdir(os.path.join(argyll_dir, "..", "ref")):
 		dirs.append(os.path.dirname(argyll_dir))
 	dirs.extend(extra_data_dirs)
@@ -624,6 +626,7 @@ cfg = ConfigParser.RawConfigParser()
 cfg.optionxform = str
 
 valid_ranges = {
+	"3dlut.hdr_peak_luminance": [120, 10000],
 	"3dlut.trc_gamma": [0.000001, 10],
 	"3dlut.trc_output_offset": [0.0, 1.0],
 	"app.port": [1, 65535],
@@ -659,12 +662,13 @@ valid_values = {
 	# collink: xvYCC output encoding is not supported
 	"3dlut.encoding.output": filter(lambda v: v not in ("T", "x", "X"),
 									video_encodings),
-	"3dlut.format": ["3dl", "cube", "eeColor", "madVR", "mga", "png", "ReShade",
-					 "spi3d"],
+	"3dlut.format": ["3dl", "cube", "eeColor", "icc", "madVR", "mga", "png",
+					 "ReShade", "spi3d"],
 	"3dlut.image.layout": ["h", "v"],
 	"3dlut.image.order": ["rgb", "bgr"],
 	"3dlut.rendering_intent": intents,
-	"3dlut.size": [16, 17, 24, 32, 33, 64, 65],
+	"3dlut.size": [5, 9, 16, 17, 24, 32, 33, 64, 65],
+	"3dlut.trc": ["bt1886", "customgamma", "gamma2.2", "smpte2084.hardclip", "smpte2084.rolloffclip"],
 	"3dlut.trc_gamma_type": ["b", "B"],
 	"calibration.quality": ["v", "l", "m", "h", "u"],
 	"colorimeter_correction.observer": observers,
@@ -700,8 +704,8 @@ valid_values = {
 	"synthprofile.trc_gamma_type": ["g", "G"],
 	"tc_algo": ["", "t", "r", "R", "q", "Q", "i", "I"],  # Q = Argyll >= 1.1.0
 	"tc_vrml_use_D50": [0, 1],
-	"tc_vrml_cie_colorspace": ["DIN99", "DIN99b", "DIN99c", "DIN99d", "LCH(ab)",
-							   "LCH(uv)", "Lab", "Luv", "Lu'v'", "xyY"],
+	"tc_vrml_cie_colorspace": ["DIN99", "DIN99b", "DIN99c", "DIN99d", "ICtCp",
+							   "LCH(ab)", "LCH(uv)", "Lab", "Luv", "Lu'v'", "xyY"],
 	"tc_vrml_device_colorspace": ["HSI", "HSL", "HSV", "RGB"],
 	"testchart.auto_optimize": [0, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18],
 	"trc": ["240", "709", "l", "s", ""],
@@ -711,13 +715,27 @@ valid_values = {
 	"whitepoint.colortemp.locus": ["t", "T"]
 }
 
+content_rgb_space = colormath.get_rgb_space("DCI P3")
+crx, cry = content_rgb_space[2:][0][:2]
+cgx, cgy = content_rgb_space[2:][1][:2]
+cbx, cby = content_rgb_space[2:][2][:2]
+cwx, cwy = colormath.XYZ2xyY(*content_rgb_space[1])[:2]
 defaults = {
 	"3d.format": "HTML",
 	"3dlut.apply_black_offset": 0,
 	"3dlut.apply_trc": 1,
 	"3dlut.bitdepth.input": 10,
 	"3dlut.bitdepth.output": 12,
+	"3dlut.content.colorspace.blue.x": cbx,
+	"3dlut.content.colorspace.blue.y": cby,
+	"3dlut.content.colorspace.green.x": cgx,
+	"3dlut.content.colorspace.green.y": cgy,
+	"3dlut.content.colorspace.red.x": crx,
+	"3dlut.content.colorspace.red.y": cry,
+	"3dlut.content.colorspace.white.x": cwx,
+	"3dlut.content.colorspace.white.y": cwy,
 	"3dlut.create": 0,
+	"3dlut.trc": "bt1886",
 	"3dlut.trc_gamma": 2.4,
 	"3dlut.trc_gamma.backup": 2.4,
 	"3dlut.trc_gamma_type": "B",
@@ -728,6 +746,8 @@ defaults = {
 	"3dlut.encoding.output.backup": "n",
 	"3dlut.format": "cube",
 	"3dlut.gamap.use_b2a": 0,
+	"3dlut.hdr_maxcll": 10000,
+	"3dlut.hdr_peak_luminance": 400,
 	"3dlut.image.layout": "h",
 	"3dlut.image.order": "rgb",
 	"3dlut.input.profile": "",
@@ -922,12 +942,15 @@ defaults = {
 	"profile.update": 0,
 	"profile_loader.check_gamma_ramps": 0,
 	"profile_loader.error.show_msg": 1,
+	"profile_loader.exceptions": "",
 	"profile_loader.fix_profile_associations": 0,
 	"profile_loader.known_apps": ";".join(["basiccolor display.exe",
 										   "calclient.exe",
 										   "coloreyes display pro.exe",
+										   "colorhcfr.exe",
 										   "colormunkidisplay.exe",
 										   "colornavigator.exe",
+										   "cpkeeper.exe",
 										   "dell ultrasharp calibration solution.exe",
 										   "hp_dreamcolor_calibration_solution.exe",
 										   "i1profiler.exe",
@@ -1016,7 +1039,6 @@ defaults = {
 	"tc_white_patches": 4,
 	"tc.show": 0,
 	"testchart.auto_optimize": 5,
-	"testchart.auto_optimize.fix_zero_blackpoint": 0,
 	"testchart.file": "auto",
 	"testchart.file.backup": "auto",
 	"testchart.reference": "",
@@ -1189,6 +1211,8 @@ def getcfg(name, fallback=True, raw=False):
 		if debug > 1:
 			print name, "- falling back to", value
 	elif name in ("displays", "instruments"):
+		if not value:
+			return []
 		value = [strtr(v, [("%" + hex(ord(os.pathsep))[2:].upper(), os.pathsep),
 						   ("%25", "%")]) for v in value.split(os.pathsep)]
 	return value
@@ -1470,7 +1494,9 @@ def initcfg(module=None):
 		setcfg("calibration.file", defaults["calibration.file"])
 	# Read cfg
 	cfgnames = []
-	if module != "3DLUT-maker":
+	if module != "3DLUT-maker" and (module != "apply-profiles" or
+									sys.platform != "win32"):
+		# Never read base app cfg for 3D LUT maker or for Windows profile loader
 		cfgnames.append(appbasename)
 	if module:
 		cfgnames.append(cfgbasename)
